import {
  Body,
  Controller,
  Del,
  Get,
  Inject,
  Param,
  Post,
  Query,
} from '@midwayjs/decorator';
import { BaseController } from 'free-midway-component';
import { NurseService } from '../service/nurse.service';
import {
  CDTO_nurse,
  CVO_nurse,
  FVO_nurse,
  QDTO_nurse,
  QVO_nurse,
  UDTO_nurse,
  UVAO_nurse,
} from '../interface/nurse.interface';
import { ApiResponse, ApiTags, ApiQuery } from '@midwayjs/swagger';
import { Validate } from '@midwayjs/validate';
@ApiTags(['护士'])
@Controller('/nurse')
export class NurseController extends BaseController {
  @Inject()
  service: NurseService;

  @Post('/')
  @Validate()
  @ApiResponse({ type: CVO_nurse })
  async create(@Body() data: CDTO_nurse) {
    const dbData = await this.service.create(data);
    const result = new CVO_nurse(dbData);
    return result;
  }
  @Get('/')
  @ApiQuery({ name: 'query' })
  @ApiResponse({ type: QVO_nurse })
  async query(
    @Query() filter: QDTO_nurse,
    @Query('skip') skip: number,
    @Query('limit') limit: number
  ) {
    const list = await this.service.query(filter, { skip, limit });
    const data = [];
    for (const i of list) {
      const newData = new QVO_nurse(i);
      data.push(newData);
    }
    const total = await this.service.count(filter);
    return { data, total };
  }

  @Get('/:id')
  @ApiResponse({ type: FVO_nurse })
  async fetch(@Param('id') id: string) {
    const data = await this.service.fetch(id);
    const result = new FVO_nurse(data);
    return result;
  }

  @Post('/:id')
  @Validate()
  @ApiResponse({ type: UVAO_nurse })
  async update(@Param('id') id: string, @Body() body: UDTO_nurse) {
    const result = await this.service.updateOne(id, body);
    return result;
  }

  @Del('/:id')
  @Validate()
  async delete(@Param('id') id: string) {
    await this.service.delete(id);
    return 'ok';
  }
  async createMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async updateMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }

  async deleteMany(...args: any[]) {
    throw new Error('Method not implemented.');
  }
}
